@@ -2,6 +2,8 @@ if(!file.exists("../windows/jq/include/jq.h")){
   unlink("../windows", recursive = TRUE)
   url <- if(grepl("aarch", R.version$platform)){
     "https://github.com/r-windows/bundles/releases/download/jq-1.7/jq-1.7-clang-aarch64.tar.xz"
+  } else if(grepl("clang", Sys.getenv('R_COMPILED_BY'))){
+    "https://github.com/r-windows/bundles/releases/download/jq-1.7/jq-1.7-clang-x86_64.tar.xz"
   } else if(getRversion() >= "4.2") {
     "https://github.com/r-windows/bundles/releases/download/jq-1.7/jq-1.7-ucrt-x86_64.tar.xz"
   } else {
